@@ -6,12 +6,7 @@ from cachepot.expire import ExpireSeconds
 
 
 class CacheBackendProtocol(Protocol):
-
-    def save(self,
-             key: bytes,
-             value: bytes,
-             *,
-             expire_seconds: ExpireSeconds) -> None:
+    def save(self, key: bytes, value: bytes, *, expire_seconds: ExpireSeconds) -> None:
         ...
 
     def load(self, key: bytes) -> Optional[bytes]:
