@@ -2,7 +2,7 @@ from typing import TypeVar
 
 from typing_extensions import Protocol
 
-T = TypeVar('T')
+T = TypeVar("T")
 
 
 class SerializerProtocol(Protocol[T]):
